@@ -375,8 +375,8 @@ def features(df, **kargs):
         cols = list(df.dtypes[df.dtypes.apply(lambda x: x in [i])].index)
         rtn.loc[i, 'columns'] = ', '.join(cols)
     if params['plot']:
-        rtn['dtypes'].plot.barh(figsize=params['figsize'], cmap=params['cmap'],
-                                color=params['color'], width=params['width'], alpha=params['alpha'])
+        rtn['dtypes'].plot.barh(figsize=params['figsize'], 
+            color=params['color'], width=params['width'], alpha=params['alpha'])
         plt.show()
     return rtn
 
@@ -385,16 +385,16 @@ def info(df, **kargs):
     params = init_params({'func': 'info'}, **kargs)
     rtn = pd.DataFrame(
         data={'dtypes': [ str(y) for x, y in df.dtypes.items() ],
-              'count': np.round(df.count().values, params['round']),
-              'nunique': np.round(df.nunique().values, params['round']),
-              'nduplicate': np.round(df.count().values-df.nunique().values, params['round']),
-              'na': np.round(df.isna().sum().values, params['round'])},
+            'count': np.round(df.count().values, params['round']),
+            'nunique': np.round(df.nunique().values, params['round']),
+            'nduplicate': np.round(df.count().values-df.nunique().values, params['round']),
+            'na': np.round(df.isna().sum().values, params['round'])},
         index=df.columns)
     if params['sort']:
         rtn = rtn.sort_values(params['by'], ascending=params['ascending'])
     if params['plot']:
         rtn.plot.bar(figsize=params['figsize'], cmap=params['cmap'],
-                     width=params['width'], alpha=params['alpha'])
+            width=params['width'], alpha=params['alpha'])
         plt.xticks(rotation=params['rotation'])
         plt.show()
     return rtn
@@ -559,8 +559,9 @@ def corr(df, **kargs):
         rtn = rtn.sort_values(params['by'], ascending=params['ascending'])
     if params['plot']:
         plt.figure(figsize=params['figsize'])
-        sns.heatmap(data=df_cor, annot=True, vmax=1, vmin=-
-                    1, cmap='RdBu', linewidths=.5, fmt='.2g')
+        sns.heatmap(data=df_cor, annot=True, 
+            vmax=1, vmin=-1, 
+            cmap='RdBu', linewidths=.5, fmt='.2g')
         plt.show()
     return rtn
 
@@ -689,7 +690,7 @@ def xcorr(df, **kargs):
         rtn = rtn.sort_values(params['by'], ascending=params['ascending'])
     if params['plot']:
         rtn.plot.bar(figsize=params['figsize'], cmap=params['cmap'],
-                     width=params['width'], alpha=params['alpha'])
+            width=params['width'], alpha=params['alpha'])
         plt.xticks(rotation=params['rotation'])
         plt.title(params['title'])
         plt.show()
@@ -725,16 +726,16 @@ def ximportance(df, **kargs):
         model4 = LGBMRegressor(n_estimators=100).fit(X, y)
     rtn = pd.DataFrame(
         data={model1.__class__.__name__: pre_scale(model1.feature_importances_, 'minmax'),
-              model2.__class__.__name__: pre_scale(model2.feature_importances_, 'minmax'),
-              model3.__class__.__name__: pre_scale(model3.feature_importances_, 'minmax'),
-              model4.__class__.__name__: pre_scale(model4.feature_importances_, 'minmax')},
+            model2.__class__.__name__: pre_scale(model2.feature_importances_, 'minmax'),
+            model3.__class__.__name__: pre_scale(model3.feature_importances_, 'minmax'),
+            model4.__class__.__name__: pre_scale(model4.feature_importances_, 'minmax')},
         index=X.columns)
     rtn['mean'] = rtn.mean(axis=1)
     if params['sort']:
         rtn = rtn.sort_values(params['by'], ascending=params['ascending'])
     if params['plot']:
         rtn.iloc[:10, :-1].plot.bar(figsize=params['figsize'], cmap=params['cmap'],
-                                    width=params['width'], alpha=params['alpha'])
+            width=params['width'], alpha=params['alpha'])
         plt.xticks(rotation=params['rotation'])
         plt.title(params['title'])
         plt.show()
@@ -751,14 +752,14 @@ def xvif(df, **kargs):
                    'int32', 'int64', 'float32', 'float64'])].index)]
     rtn = pd.DataFrame(
         data=[variance_inflation_factor(tmp.values, i)
-              for i in range(tmp.shape[1])],
+            for i in range(tmp.shape[1])],
         columns=['vif'],
         index=tmp.columns)
     if params['sort']:
         rtn = rtn.sort_values(params['by'], ascending=params['ascending'])
     if params['plot']:
         rtn.plot.bar(figsize=params['figsize'], cmap=params['cmap'],
-                     width=params['width'], alpha=params['alpha'])
+            width=params['width'], alpha=params['alpha'])
         plt.xticks(rotation=params['rotation'])
         plt.title(params['title'])
         plt.show()
@@ -800,8 +801,11 @@ def plt_dist(df, params=None, **kargs):
     ncol = params['cols'] if Xcols > params['cols'] else Xcols
     nrow = 1 if ncol < params['cols'] else int(np.ceil(Xcols/ncol))
     if params['kind'] == 'box':
-        X.plot(kind='box', subplots=True, layout=(nrow, ncol),
-               color=params['color'], figsize=(params['figsize'][0], 3*nrow))
+        X.plot(kind='box', 
+            subplots=True, 
+            layout=(nrow, ncol),
+            color=params['color'], 
+            figsize=(params['figsize'][0], 3*nrow))
     else:
         _, ax = plt.subplots(nrow, ncol, figsize=(
             params['figsize'][0], 3*nrow))
@@ -816,17 +820,17 @@ def plt_dist(df, params=None, **kargs):
             if params['kind'] == 'kde':
                 if params['target']:
                     p = sns.histplot(data=X, x=f, kde=True, stat='density', hue=params['target'], alpha=params['alpha'], color=params['color'],
-                                     palette=params['palette'], bins=params['bins'], multiple='stack', ax=axs)
+                        palette=params['palette'], bins=params['bins'], multiple='stack', ax=axs)
                 else:
                     p = sns.histplot(data=X, x=f, kde=True, stat='density', alpha=params['alpha'], color=params['color'],
-                                     palette=params['palette'], bins=params['bins'], multiple='stack', ax=axs)
+                        palette=params['palette'], bins=params['bins'], multiple='stack', ax=axs)
             elif params['kind'] == 'hist':
                 if params['target']:
                     p = sns.histplot(data=X, x=f, hue=params['target'], alpha=params['alpha'], color=params['color'],
-                                     palette=params['palette'], bins=params['bins'], multiple='stack', stat='count', ax=axs)
+                        palette=params['palette'], bins=params['bins'], multiple='stack', stat='count', ax=axs)
                 else:
                     p = sns.histplot(data=X, x=f, alpha=params['alpha'], color=params['color'],
-                                     palette=params['palette'], bins=params['bins'], multiple='stack', stat='count', ax=axs)
+                        palette=params['palette'], bins=params['bins'], multiple='stack', stat='count', ax=axs)
             if i > 0:
                 p.legend([], [], frameon=False)
             p.set_xlabel(f, fontsize=10)
